==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/CascadeToHashtable.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o.foundation;
using j4o.lang;
using j4o.util;
using com.db4o;
namespace com.db4o.test 
{

	public class CascadeToHashtable 
	{
      
		public CascadeToHashtable() : base() 
		{
		}
		internal System.Collections.Hashtable ht;
      
		public void configure() 
		{
			Db4o.configure().objectClass(this).cascadeOnUpdate(true);
			Db4o.configure().objectClass(this).cascadeOnDelete(true);
		}
      
		public void store() 
		{
			Tester.deleteAllInstances(this);
			Tester.deleteAllInstances(new Atom());
			CascadeToHashtable cth1 = new CascadeToHashtable();
			cth1.ht = new System.Collections.Hashtable();
			cth1.ht.Add("key1", new Atom("stored1"));
			cth1.ht.Add("key2", new Atom(new Atom("storedChild1"), "stored2"));
			Tester.store(cth1);
		}
      
		public void test() 
		{
			Tester.forEach(this, new MyVisitorCTH1());
			Tester.reOpen();
			Tester.forEach(this, new MyVisitorCTH2());
			Tester.reOpen();
			Tester.deleteAllInstances(this);
			Tester.ensureOccurrences(new Atom(), 1);
		}
	}

	public class MyVisitorCTH1:Visitor4
	{
		public void visit(Object obj) 
		{
			CascadeToHashtable cth1 = (CascadeToHashtable)obj;
			cth1.ht["key1"] = new Atom("updated1");
			Atom atom1 = (Atom)cth1.ht["key2"];
			atom1.name = "updated2";
			Tester.store(cth1);
		}
	}



	public class MyVisitorCTH2:Visitor4
	{
		public void visit(Object obj) 
		{
			CascadeToHashtable cth1 = (CascadeToHashtable)obj;
			Atom atom1 = (Atom)cth1.ht["key1"];
			Tester.ensure(atom1.name.Equals("updated1"));
			atom1 = (Atom)cth1.ht["key2"];
			Tester.ensure(atom1.name.Equals("updated2"));
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/CascadeToHashtable.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o.foundation;
using j4o.lang;
using j4o.util;
using com.db4o;
namespace com.db4o.test 
{

	public class CascadeToHashtable 
	{
      
		public CascadeToHashtable() : base() 
		{
		}
		internal System.Collections.Hashtable ht;
      
		public void Configure() 
		{
			Db4o.Configure().ObjectClass(this).CascadeOnUpdate(true);
			Db4o.Configure().ObjectClass(this).CascadeOnDelete(true);
		}
      
		public void Store() 
		{
			Tester.DeleteAllInstances(this);
			Tester.DeleteAllInstances(new Atom());
			CascadeToHashtable cth1 = new CascadeToHashtable();
			cth1.ht = new System.Collections.Hashtable();
			cth1.ht.Add("key1", new Atom("stored1"));
			cth1.ht.Add("key2", new Atom(new Atom("storedChild1"), "stored2"));
			Tester.Store(cth1);
		}
      
		public void Test() 
		{
			Tester.ForEach(this, new MyVisitorCTH1());
			Tester.ReOpen();
			Tester.ForEach(this, new MyVisitorCTH2());
			Tester.ReOpen();
			Tester.DeleteAllInstances(this);
			Tester.EnsureOccurrences(new Atom(), 1);
		}
	}

	public class MyVisitorCTH1:Visitor4
	{
		public void Visit(Object obj) 
		{
			CascadeToHashtable cth1 = (CascadeToHashtable)obj;
			cth1.ht["key1"] = new Atom("updated1");
			Atom atom1 = (Atom)cth1.ht["key2"];
			atom1.name = "updated2";
			Tester.Store(cth1);
		}
	}



	public class MyVisitorCTH2:Visitor4
	{
		public void Visit(Object obj) 
		{
			CascadeToHashtable cth1 = (CascadeToHashtable)obj;
			Atom atom1 = (Atom)cth1.ht["key1"];
			Tester.Ensure(atom1.name.Equals("updated1"));
			atom1 = (Atom)cth1.ht["key2"];
			Tester.Ensure(atom1.name.Equals("updated2"));
		}
	}
}
